summaryrefslogtreecommitdiffstats
path: root/kaudiocreator
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
commitf59dfa08651a47f21d004e8e4cb5020b8035287e (patch)
tree0582273566661474af14fe8f1737cfe1e6527d46 /kaudiocreator
parent83fbc82a101309e171089f0d5ed080f82a367345 (diff)
downloadtdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.tar.gz
tdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 83fbc82a101309e171089f0d5ed080f82a367345.
Diffstat (limited to 'kaudiocreator')
-rw-r--r--kaudiocreator/cdconfig.ui2
-rw-r--r--kaudiocreator/encodefile.ui26
-rw-r--r--kaudiocreator/encodefileimp.cpp2
-rw-r--r--kaudiocreator/encoder.cpp16
-rw-r--r--kaudiocreator/encoderconfig.ui10
-rw-r--r--kaudiocreator/encoderconfigimp.cpp4
-rw-r--r--kaudiocreator/encoderedit.ui4
-rw-r--r--kaudiocreator/encoderoutput.ui2
-rw-r--r--kaudiocreator/general.ui6
-rw-r--r--kaudiocreator/infodialog.ui20
-rw-r--r--kaudiocreator/jobque.ui4
-rw-r--r--kaudiocreator/jobqueimp.cpp20
-rw-r--r--kaudiocreator/kaudiocreator.cpp26
-rw-r--r--kaudiocreator/kaudiocreator.h2
-rw-r--r--kaudiocreator/ripconfig.ui2
-rw-r--r--kaudiocreator/ripper.cpp10
-rw-r--r--kaudiocreator/tracks.ui8
-rw-r--r--kaudiocreator/tracksimp.cpp10
-rw-r--r--kaudiocreator/wizard.ui8
-rw-r--r--kaudiocreator/wizard.ui.h2
20 files changed, 92 insertions, 92 deletions
diff --git a/kaudiocreator/cdconfig.ui b/kaudiocreator/cdconfig.ui
index c0756c83..cc317a9e 100644
--- a/kaudiocreator/cdconfig.ui
+++ b/kaudiocreator/cdconfig.ui
@@ -45,7 +45,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kaudiocreator/encodefile.ui b/kaudiocreator/encodefile.ui
index 93a4055f..ccbb6313 100644
--- a/kaudiocreator/encodefile.ui
+++ b/kaudiocreator/encodefile.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout5</cstring>
+ <cstring>tqlayout5</cstring>
</property>
<hbox>
<property name="name">
@@ -74,7 +74,7 @@
<property name="text">
<string>Track:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -85,7 +85,7 @@
<property name="text">
<string>Comment:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -101,7 +101,7 @@
<property name="text">
<string>Title:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -114,7 +114,7 @@
<property name="text">
<string>Artist:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -153,7 +153,7 @@
<property name="text">
<string>Artist:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -166,7 +166,7 @@
<property name="text">
<string>Album:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -192,7 +192,7 @@
<property name="text">
<string>Year:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -205,7 +205,7 @@
<property name="text">
<string>Genre:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -223,7 +223,7 @@
<property name="text">
<string>Comment:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -244,7 +244,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -267,7 +267,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout4</cstring>
+ <cstring>tqlayout4</cstring>
</property>
<hbox>
<property name="name">
@@ -283,7 +283,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>121</width>
<height>20</height>
diff --git a/kaudiocreator/encodefileimp.cpp b/kaudiocreator/encodefileimp.cpp
index 59f32405..28d46320 100644
--- a/kaudiocreator/encodefileimp.cpp
+++ b/kaudiocreator/encodefileimp.cpp
@@ -70,7 +70,7 @@ void EncodeFileImp::encode(){
int counter(1);
KMessageBox::information(this,
i18n("%1 Job(s) have been started. You can watch their progress in the " \
- "jobs section.").arg(counter),
+ "jobs section.").tqarg(counter),
i18n("Jobs have started"), i18n("Jobs have started"));
}
diff --git a/kaudiocreator/encoder.cpp b/kaudiocreator/encoder.cpp
index 0be1fef1..e528a29a 100644
--- a/kaudiocreator/encoder.cpp
+++ b/kaudiocreator/encoder.cpp
@@ -31,7 +31,7 @@
#include <kurl.h>
#include <kdebug.h>
#include <knotifyclient.h>
-#include <textedit.h>
+#include <tqtextedit.h>
#include <kinputdialog.h>
/**
@@ -53,7 +53,7 @@ void Encoder::loadSettings() {
EncoderPrefs* Encoder::loadEncoder( int encoder ){
EncoderPrefs* prefs;
- TQString currentEncoderGroup = TQString("Encoder_%1").arg(encoder);
+ TQString currentEncoderGroup = TQString("Encoder_%1").tqarg(encoder);
prefs = EncoderPrefs::prefs(currentEncoderGroup);
if ( !EncoderPrefs::hasPrefs(currentEncoderGroup) ) {
KMessageBox::sorry(0, i18n("No encoder has been selected.\nPlease select an encoder in the configuration."), i18n("No Encoder Selected"));
@@ -132,8 +132,8 @@ void Encoder::removeJob(int id ) {
* @param job the job to encode.
*/
void Encoder::encodeWav(Job *job ) {
- emit(addJob(job, i18n("Encoding (%1): %2 - %3").arg(loadEncoder(job->encoder)->extension())
- .arg(job->track_artist).arg(job->track_title)));
+ emit(addJob(job, i18n("Encoding (%1): %2 - %3").tqarg(loadEncoder(job->encoder)->extension())
+ .tqarg(job->track_artist).tqarg(job->track_title)));
pendingJobs.append(job);
tendToNewJobs();
}
@@ -252,12 +252,12 @@ void Encoder::receivedThreadOutput(KProcess *process, char *buffer, int length )
reportCount++;
return;
}
- //qDebug(TQString("Pre cropped: %1").arg(output).latin1());
+ //qDebug(TQString("Pre cropped: %1").tqarg(output).latin1());
output = output.mid(output.find('%')-loadEncoder(job->encoder)->percentLength(),2);
- //qDebug(TQString("Post cropped: %1").arg(output).latin1());
+ //qDebug(TQString("Post cropped: %1").tqarg(output).latin1());
bool conversionSuccessfull = false;
int percent = output.toInt(&conversionSuccessfull);
- //qDebug(TQString("number: %1").arg(percent).latin1());
+ //qDebug(TQString("number: %1").tqarg(percent).latin1());
if ( percent >= 0 && percent < 100 && conversionSuccessfull ) {
emit(updateProgress(job->id, percent));
}
@@ -284,7 +284,7 @@ void Encoder::jobDone(KProcess *process ) {
bool showDebugBox = false;
if ( process->exitStatus() == 127 ) {
- KMessageBox::sorry(0, i18n("The selected encoder was not found.\nThe wav file has been removed. Command was: %1").arg(job->errorString), i18n("Encoding Failed"));
+ KMessageBox::sorry(0, i18n("The selected encoder was not found.\nThe wav file has been removed. Command was: %1").tqarg(job->errorString), i18n("Encoding Failed"));
emit(updateProgress(job->id, -1));
}
else if ( TQFile::exists(job->newLocation) ) {
diff --git a/kaudiocreator/encoderconfig.ui b/kaudiocreator/encoderconfig.ui
index 51e00ef1..67f256c0 100644
--- a/kaudiocreator/encoderconfig.ui
+++ b/kaudiocreator/encoderconfig.ui
@@ -131,7 +131,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -140,7 +140,7 @@
</spacer>
<widget class="TQLayoutWidget" row="3" column="0" rowspan="1" colspan="3">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
@@ -188,7 +188,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>30</height>
@@ -241,7 +241,7 @@
<property name="text">
<string>Lowest</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -252,7 +252,7 @@
<property name="text">
<string>Normal</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignCenter</set>
</property>
</widget>
diff --git a/kaudiocreator/encoderconfigimp.cpp b/kaudiocreator/encoderconfigimp.cpp
index e49dd6a9..98321887 100644
--- a/kaudiocreator/encoderconfigimp.cpp
+++ b/kaudiocreator/encoderconfigimp.cpp
@@ -93,7 +93,7 @@ void EncoderConfigImp::loadEncoderList(){
int lastKnownEncoder = Prefs::lastKnownEncoder();
lastKnownEncoder++;
for( int i=0; i<=lastKnownEncoder; i++ ){
- TQString currentGroup = TQString("Encoder_%1").arg(i);
+ TQString currentGroup = TQString("Encoder_%1").tqarg(i);
if(EncoderPrefs::hasPrefs(currentGroup)){
lastEncoder = i;
EncoderPrefs *encPrefs = EncoderPrefs::prefs(currentGroup);
@@ -123,7 +123,7 @@ void EncoderConfigImp::addEncoderSlot(){
uint number = 0;
TQString groupName;
while(!foundEmptyGroup){
- groupName = TQString("Encoder_%1").arg(number);
+ groupName = TQString("Encoder_%1").tqarg(number);
if(!EncoderPrefs::hasPrefs(groupName))
foundEmptyGroup = true;
else
diff --git a/kaudiocreator/encoderedit.ui b/kaudiocreator/encoderedit.ui
index 1023611b..f5c3c072 100644
--- a/kaudiocreator/encoderedit.ui
+++ b/kaudiocreator/encoderedit.ui
@@ -28,7 +28,7 @@
<property name="name">
<cstring>kcfg_encoderName</cstring>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>320</width>
<height>0</height>
@@ -80,7 +80,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/kaudiocreator/encoderoutput.ui b/kaudiocreator/encoderoutput.ui
index 8851d0f4..94779b68 100644
--- a/kaudiocreator/encoderoutput.ui
+++ b/kaudiocreator/encoderoutput.ui
@@ -63,7 +63,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kaudiocreator/general.ui b/kaudiocreator/general.ui
index f372e507..765cbb1c 100644
--- a/kaudiocreator/general.ui
+++ b/kaudiocreator/general.ui
@@ -65,7 +65,7 @@
<string>Regular expression used on all file names. For example using selection " " and replace with "_" would replace all the spaces with underlines.
</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
@@ -194,7 +194,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<grid>
<property name="name">
@@ -240,7 +240,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/kaudiocreator/infodialog.ui b/kaudiocreator/infodialog.ui
index 5a22fb56..1add6372 100644
--- a/kaudiocreator/infodialog.ui
+++ b/kaudiocreator/infodialog.ui
@@ -46,7 +46,7 @@
<property name="text">
<string>Comment:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -62,7 +62,7 @@
<property name="text">
<string>Title:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -80,7 +80,7 @@
<property name="text">
<string>Artist:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -114,7 +114,7 @@
<property name="text">
<string>Artist:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -127,7 +127,7 @@
<property name="text">
<string>Album:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -153,7 +153,7 @@
<property name="text">
<string>Year:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -166,7 +166,7 @@
<property name="text">
<string>Genre:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="hAlign" stdset="0">
@@ -184,7 +184,7 @@
<property name="text">
<string>Comment:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
@@ -205,7 +205,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>100</height>
@@ -214,7 +214,7 @@
</spacer>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
diff --git a/kaudiocreator/jobque.ui b/kaudiocreator/jobque.ui
index eb158f54..3c76a257 100644
--- a/kaudiocreator/jobque.ui
+++ b/kaudiocreator/jobque.ui
@@ -45,7 +45,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -106,7 +106,7 @@
<property name="text">
<string>No jobs are in the queue</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignCenter</set>
</property>
<property name="hAlign" stdset="0">
diff --git a/kaudiocreator/kaudiocreator.cpp b/kaudiocreator/kaudiocreator.cpp
index c5db6337..91c0de17 100644
--- a/kaudiocreator/kaudiocreator.cpp
+++ b/kaudiocreator/kaudiocreator.cpp
@@ -92,7 +92,7 @@ KAudioCreator::KAudioCreator( TQWidget* parent, const char* name) :
TQT_SLOT( startSession() ), actionCollection(), "rip_selected" );
rip->setEnabled( false );
- connect( jobQue, TQT_SIGNAL( removeJob(int) ), TQT_TQOBJECT(this), TQT_SLOT( updateStatus() ) );
+ connect( jobQue, TQT_SIGNAL( removeJob(int) ), TQT_TQOBJECT(this), TQT_SLOT( updatetqStatus() ) );
connect( jobQue, TQT_SIGNAL( removeJob(int) ), TQT_TQOBJECT(ripper), TQT_SLOT( removeJob(int) ) );
connect( jobQue, TQT_SIGNAL( removeJob(int) ), TQT_TQOBJECT(encoder), TQT_SLOT( removeJob(int)) );
@@ -100,11 +100,11 @@ KAudioCreator::KAudioCreator( TQWidget* parent, const char* name) :
connect( ripper, TQT_SIGNAL( addJob(Job*, const TQString &) ), TQT_TQOBJECT(jobQue), TQT_SLOT( addJob(Job*, const TQString &)) );
connect( ripper, TQT_SIGNAL( eject(const TQString &) ) , TQT_TQOBJECT(tracks), TQT_SLOT( ejectDevice(const TQString &)) );
connect( ripper, TQT_SIGNAL( encodeWav(Job *) ) , TQT_TQOBJECT(encoder), TQT_SLOT( encodeWav(Job *)) );
- connect( ripper, TQT_SIGNAL( jobsChanged() ) , TQT_TQOBJECT(this), TQT_SLOT( updateStatus() ) );
+ connect( ripper, TQT_SIGNAL( jobsChanged() ) , TQT_TQOBJECT(this), TQT_SLOT( updatetqStatus() ) );
connect( encoder, TQT_SIGNAL( updateProgress(int, int) ) , TQT_TQOBJECT(jobQue), TQT_SLOT( updateProgress(int,int)) );
connect( encoder, TQT_SIGNAL( addJob(Job*, const TQString&)), TQT_TQOBJECT(jobQue), TQT_SLOT( addJob(Job*, const TQString &)) );
- connect( encoder, TQT_SIGNAL( jobsChanged() ) , TQT_TQOBJECT(this), TQT_SLOT( updateStatus() ) );
+ connect( encoder, TQT_SIGNAL( jobsChanged() ) , TQT_TQOBJECT(this), TQT_SLOT( updatetqStatus() ) );
connect( tracks, TQT_SIGNAL( hasCD(bool) ) , TQT_TQOBJECT(this), TQT_SLOT( hasCD(bool) ) );
connect( tracks, TQT_SIGNAL( ripTrack(Job *) ), TQT_TQOBJECT(ripper), TQT_SLOT( ripTrack(Job *)) );
@@ -153,10 +153,10 @@ void KAudioCreator::getRipMenu(){
ripMenu->clear();
int i=0;
- TQString currentGroup = TQString("Encoder_%1").arg(i);
+ TQString currentGroup = TQString("Encoder_%1").tqarg(i);
while(EncoderPrefs::hasPrefs(currentGroup)){
ripMenu->insertItem(EncoderPrefs::prefs(currentGroup)->encoderName(), i);
- currentGroup = TQString("Encoder_%1").arg(++i);
+ currentGroup = TQString("Encoder_%1").tqarg(++i);
}
}
@@ -170,28 +170,28 @@ void KAudioCreator::hasCD(bool cd){
statusBar()->changeItem(i18n("No Audio CD detected"), 0 );
}
-void KAudioCreator::updateStatus() {
+void KAudioCreator::updatetqStatus() {
TQString status = i18n("Idle.");
- TQString rippingStatus;
- TQString encodingStatus;
+ TQString rippingtqStatus;
+ TQString encodingtqStatus;
int activeRippingJobs = ripper->activeJobCount();
int pendingRippingJobs = ripper->pendingJobCount();
int activeEncodingJobs = encoder->activeJobCount();
int pendingEncodingJobs = encoder->pendingJobCount();
if ( activeRippingJobs ) {
- rippingStatus = i18n("Ripping (%1 active, %2 queued)").arg( activeRippingJobs ).arg( pendingRippingJobs );
- status = rippingStatus;
+ rippingtqStatus = i18n("Ripping (%1 active, %2 queued)").tqarg( activeRippingJobs ).tqarg( pendingRippingJobs );
+ status = rippingtqStatus;
}
if ( activeEncodingJobs ) {
- encodingStatus = i18n("Encoding (%1 active, %2 queued)").arg( activeEncodingJobs ).arg( pendingEncodingJobs );
+ encodingtqStatus = i18n("Encoding (%1 active, %2 queued)").tqarg( activeEncodingJobs ).tqarg( pendingEncodingJobs );
if ( activeRippingJobs ) {
status.append(" : ");
- status.append( encodingStatus );
+ status.append( encodingtqStatus );
}
else {
- status = encodingStatus;
+ status = encodingtqStatus;
}
}
diff --git a/kaudiocreator/kaudiocreator.h b/kaudiocreator/kaudiocreator.h
index 64bca008..5e901d77 100644
--- a/kaudiocreator/kaudiocreator.h
+++ b/kaudiocreator/kaudiocreator.h
@@ -47,7 +47,7 @@ protected:
private slots:
void showSettings();
- void updateStatus();
+ void updatetqStatus();
void hasCD(bool);
void configureNotifications();
diff --git a/kaudiocreator/ripconfig.ui b/kaudiocreator/ripconfig.ui
index 7d655de1..8c47615b 100644
--- a/kaudiocreator/ripconfig.ui
+++ b/kaudiocreator/ripconfig.ui
@@ -151,7 +151,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>280</height>
diff --git a/kaudiocreator/ripper.cpp b/kaudiocreator/ripper.cpp
index cb9c012b..2e953ce6 100644
--- a/kaudiocreator/ripper.cpp
+++ b/kaudiocreator/ripper.cpp
@@ -120,7 +120,7 @@ void Ripper::removeJob(int id){
pendingJobs.remove(job);
delete job;
}
- //qDebug(TQString("Done removing Job:%1").arg(id).latin1());
+ //qDebug(TQString("Done removing Job:%1").tqarg(id).latin1());
tendToNewJobs();
}
@@ -132,7 +132,7 @@ void Ripper::removeJob(int id){
void Ripper::ripTrack(Job *job){
if(!job)
return;
- emit(addJob(job, i18n("Ripping: %1 - %2").arg(job->track_artist).arg(job->track_title)));
+ emit(addJob(job, i18n("Ripping: %1 - %2").tqarg(job->track_artist).tqarg(job->track_title)));
pendingJobs.append(job);
tendToNewJobs();
}
@@ -172,12 +172,12 @@ void Ripper::tendToNewJobs(){
TQString wavFile;
TQString args = job->device;
if(!args.isEmpty())
- args = TQString("?device=%1").arg(args);
+ args = TQString("?device=%1").tqarg(args);
args = args+"&fileNameTemplate=Track %{number}";
if(job->track < 10)
- wavFile = TQString("audiocd:/Wav/Track 0%1.wav%2").arg(job->track).arg(args);
+ wavFile = TQString("audiocd:/Wav/Track 0%1.wav%2").tqarg(job->track).tqarg(args);
else
- wavFile = TQString("audiocd:/Wav/Track %1.wav%2").arg(job->track).arg(args);
+ wavFile = TQString("audiocd:/Wav/Track %1.wav%2").tqarg(job->track).tqarg(args);
KURL source(wavFile);
KURL dest(tmp.name());
diff --git a/kaudiocreator/tracks.ui b/kaudiocreator/tracks.ui
index 0f9a5743..8b7e5a5e 100644
--- a/kaudiocreator/tracks.ui
+++ b/kaudiocreator/tracks.ui
@@ -35,7 +35,7 @@
<property name="text">
<string>Unknown Artist - Unknown Album</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>AlignCenter</set>
</property>
<property name="hAlign" stdset="0">
@@ -120,7 +120,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -147,7 +147,7 @@
</widget>
<widget class="TQLayoutWidget" row="0" column="0">
<property name="name">
- <cstring>layout6</cstring>
+ <cstring>tqlayout6</cstring>
</property>
<hbox>
<property name="name">
@@ -200,7 +200,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>246</width>
<height>20</height>
diff --git a/kaudiocreator/tracksimp.cpp b/kaudiocreator/tracksimp.cpp
index 36419871..81dbe1c9 100644
--- a/kaudiocreator/tracksimp.cpp
+++ b/kaudiocreator/tracksimp.cpp
@@ -198,7 +198,7 @@ void TracksImp::changeDevice(const TQString &file ) {
TQString errstring =
i18n("CDROM read or access error (or no audio disk in drive).\n"\
"Please make sure you have access permissions to:\n%1")
- .arg(file);
+ .tqarg(file);
KMessageBox::error(this, errstring, i18n("Error"));
}
}
@@ -247,8 +247,8 @@ void TracksImp::lookupCDDBDone(CDDB::Result result ) {
CDInfoList::iterator it;
TQStringList list;
for ( it = cddb_info.begin(); it != cddb_info.end(); ++it ) {
- list.append( TQString("%1, %2, %3").arg((*it).artist).arg((*it).title)
- .arg((*it).genre));
+ list.append( TQString("%1, %2, %3").tqarg((*it).artist).tqarg((*it).title)
+ .tqarg((*it).genre));
}
bool ok(false);
@@ -378,7 +378,7 @@ void TracksImp::startSession( int encoder )
if( Prefs::promptIfIncompleteInfo() && list.count() > 0 )
{
int r = KMessageBox::questionYesNo( this,
- i18n( "Part of the album is not set: %1.\n (To change album information click the \"Edit Information\" button.)\n Would you like to rip the selected tracks anyway?").arg(list.join(", ")), i18n("Album Information Incomplete"), i18n("Rip"), KStdGuiItem::cancel() );
+ i18n( "Part of the album is not set: %1.\n (To change album information click the \"Edit Information\" button.)\n Would you like to rip the selected tracks anyway?").tqarg(list.join(", ")), i18n("Album Information Incomplete"), i18n("Rip"), KStdGuiItem::cancel() );
if( r == KMessageBox::No )
return;
@@ -417,7 +417,7 @@ void TracksImp::startSession( int encoder )
KMessageBox::information(this,
i18n("%1 Job(s) have been started. You can watch their progress in the "
- "jobs section.").arg( selected.count() ),
+ "jobs section.").tqarg( selected.count() ),
i18n("Jobs have started"), i18n("Jobs have started"));
}
diff --git a/kaudiocreator/wizard.ui b/kaudiocreator/wizard.ui
index 34a49d8e..f289cb2d 100644
--- a/kaudiocreator/wizard.ui
+++ b/kaudiocreator/wizard.ui
@@ -51,7 +51,7 @@
<property name="textFormat">
<enum>RichText</enum>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignTop|AlignLeft</set>
</property>
</widget>
@@ -65,7 +65,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -117,7 +117,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout15</cstring>
+ <cstring>tqlayout15</cstring>
</property>
<grid>
<property name="name">
@@ -251,7 +251,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kaudiocreator/wizard.ui.h b/kaudiocreator/wizard.ui.h
index cbd6ca68..7c22638e 100644
--- a/kaudiocreator/wizard.ui.h
+++ b/kaudiocreator/wizard.ui.h
@@ -105,6 +105,6 @@ void fileWizard::fileFormatTextChanged(const TQString& text)
TQMap<TQString,TQString> map;
map.insert("extension", "mp3");
string = job.replaceSpecialChars(string, false, map);
- exampleLabel->setText(i18n("Example: %1").arg(string));
+ exampleLabel->setText(i18n("Example: %1").tqarg(string));
}
diff --git a/kaudiocreator/jobqueimp.cpp b/kaudiocreator/jobqueimp.cpp
index 81c0431d..8ca6d087 100644
--- a/kaudiocreator/jobqueimp.cpp
+++ b/kaudiocreator/jobqueimp.cpp
@@ -64,7 +64,7 @@ JobQueImp::JobQueImp( TQWidget* parent, const char* name) :
*/
TQString JobQueImp::getStringFromNumber(int number){
if(number > highestNumber){
- int diff = TQString("%1").arg(number).length() - TQString("%1").arg(highestNumber).length();
+ int diff = TQString("%1").tqarg(number).length() - TQString("%1").tqarg(highestNumber).length();
highestNumber = number;
if(diff > 0){
// We have to update all of the cells.
@@ -77,7 +77,7 @@ TQString JobQueImp::getStringFromNumber(int number){
}
TQString buffer = "";
- uint newLength = TQString("%1").arg(highestNumber).length() - TQString("%1").arg(number).length();
+ uint newLength = TQString("%1").tqarg(highestNumber).length() - TQString("%1").tqarg(number).length();
for(uint i=0; i < newLength; i++)
buffer += "0";
return buffer;
@@ -92,9 +92,9 @@ void JobQueImp::addJob(Job*job, const TQString &name ){
if(!job)
return;
job->id = ++currentId;
- QueListViewItem *currentItem = new QueListViewItem(todoQue, TQString("%1%2").arg(getStringFromNumber(currentId)).arg(currentId), "0", name);
+ QueListViewItem *currentItem = new QueListViewItem(todoQue, TQString("%1%2").tqarg(getStringFromNumber(currentId)).tqarg(currentId), "0", name);
currentItem->setPixmap(ICON_LOC, SmallIcon("player_pause", currentItem->height()-2));
- queLabel->setText(i18n("Number of jobs in the queue: %1").arg(todoQue->childCount()));
+ queLabel->setText(i18n("Number of jobs in the queue: %1").tqarg(todoQue->childCount()));
}
/**
@@ -106,7 +106,7 @@ void JobQueImp::updateProgress(int id, int progress){
int currentJobCount = numberOfJobsNotFinished();
QueListViewItem * currentItem = (QueListViewItem*)todoQue->firstChild();
TQString buffer = getStringFromNumber(id);
- buffer += TQString("%1").arg(id);
+ buffer += TQString("%1").tqarg(id);
// Find the current item
while( currentItem != NULL ){
@@ -124,7 +124,7 @@ void JobQueImp::updateProgress(int id, int progress){
return;
currentItem->percentDone = progress;
- currentItem->repaint();
+ currentItem->tqrepaint();
// Update the icon if needed
if(progress > 0 && progress < 100 && !currentItem->progressing ){
@@ -158,7 +158,7 @@ bool JobQueImp::removeJob(QueListViewItem *item, bool kill, bool prompt){
if(!item)
return false;
- if(item->percentDone < 100 && item->percentDone > -1 && (prompt && KMessageBox::questionYesNo(this, i18n("KAudioCreator has not finished %1. Remove anyway?").arg(item->text(HEADER_DESCRIPTION)), i18n("Unfinished Job in Queue"), KStdGuiItem::del(), i18n("Keep"))
+ if(item->percentDone < 100 && item->percentDone > -1 && (prompt && KMessageBox::questionYesNo(this, i18n("KAudioCreator has not finished %1. Remove anyway?").tqarg(item->text(HEADER_DESCRIPTION)), i18n("Unfinished Job in Queue"), KStdGuiItem::del(), i18n("Keep"))
== KMessageBox::No ))
return false;
@@ -180,7 +180,7 @@ bool JobQueImp::removeJob(QueListViewItem *item, bool kill, bool prompt){
currentId = 0;
}
else
- queLabel->setText(i18n("Number of jobs in the queue: %1").arg(todoQue->childCount()));
+ queLabel->setText(i18n("Number of jobs in the queue: %1").tqarg(todoQue->childCount()));
return true;
}
@@ -248,7 +248,7 @@ void JobQueImp::clearDoneJobs(){
currentId = 0;
}
else
- queLabel->setText(i18n("Number of jobs in the queue: %1").arg(todoQue->childCount()));
+ queLabel->setText(i18n("Number of jobs in the queue: %1").tqarg(todoQue->childCount()));
}
/**
@@ -270,7 +270,7 @@ int JobQueImp::numberOfJobsNotFinished(){
}
/**
* The repaint function overloaded so that we can have a built in progressbar.
*/
void QueListViewItem::paintCell (TQPainter * p,const TQColorGroup &cg,int column,
int width,int align){
@@ -270,7 +270,7 @@ int JobQueImp::numberOfJobsNotFinished(){
}
/**
- * The repaint function overloaded so that we can have a built in progressbar.
+ * The tqrepaint function overloaded so that we can have a built in progressbar.
*/
void QueListViewItem::paintCell (TQPainter * p,const TQColorGroup &cg,int column,